/*******************(C) COPYRIGHT 2019 GRAND LOTUS ************************
;* File Name           : ADC_INIT.C
;* Author              : GRAND LOTUS
;* Version             : V1.00
;* Date                : 2019/07/01
;**************************************************************************
;
;ADC初始化
;
;*************************************************************************/
#include"common.h"
//******************************************************************************************
/////////////////////ADCON0控制寄存器各位定义///////////////////////////////////////////////
//******************************************************************************************
//Bit 7 ADENB: ADC使能控制位。
//1 = 使能ADC
//0 = 关闭ADC
//Bit 6 ADS: ADC 启动位。
//1 = 开始（每次写入1将重新启动ADC）。
//0 = 停止，转换完成自动清零
//Bit 5 EOC: ADC 状态控制位 。
//1 = 转换结束， ADS 复位。
//0 = 转换过程中；
//Bit 4 ADFM: 数据格式选择位。
//1 = ADRES = {ADH[3:0]， ADL[7:0]}; ADH[7:4] = 0。
//0 = ADRES = {ADH[7:0]， ADL[7:4]}; ADL[3:0] = 0。
//Bit[3:0] CHS[3:0]: ADC 输入通道选择位。
//[0000] ~ [0111] = AIN0 ~ AIN7
//[1000] = VDD/4
//[1001] =内建 VREF 基准电平
//[1010] 未定义
//[1011] = GND
#define				ADENB_1					Bin(10000000)				//使能ADC
#define				ADENB_0					Bin(00000000)				//关闭ADC
#define				ADS_1					Bin(01000000)				//开始（每次写入1将重新启动ADC）。
#define				ADS_0					Bin(00000000)				//停止，转换完成自动清零
#define				EOC_1					Bin(00100000)				//转换结束，ADS 复位。
#define				EOC_0					Bin(00000000)				//转换过程中
#define				ADFM_1					Bin(00010000)				//数据格式ADRES = {ADH[3:0]，ADL[7:0]};  ADH[7:4] = 0。
#define				ADFM_0					Bin(00000000)				//数据格式ADRES = {ADH[7:0]，ADL[7:4]};  ADL[3:0] = 0。
#define				CHS_GND					Bin(00001011)				//ADC 输入通道选择位为（内部通道）GND
#define				CHS_VREF				Bin(00001010)				//ADC 输入通道选择位为（内部通道）内建VREF基准电平
#define				CHS_VDD_4				Bin(00001000)				//ADC 输入通道选择位为（内部通道）VDD/4
#define				CHS_AIN7				Bin(00000111)				//ADC 输入通道选择位为	AIN7
#define				CHS_AIN6				Bin(00000110)				//ADC 输入通道选择位为	AIN6
#define				CHS_AIN5				Bin(00000101)				//ADC 输入通道选择位为	AIN5
#define				CHS_AIN4				Bin(00000100)				//ADC 输入通道选择位为	AIN4
#define				CHS_AIN3				Bin(00000011)				//ADC 输入通道选择位为	AIN3
#define				CHS_AIN2				Bin(00000010)				//ADC 输入通道选择位为	AIN2
#define				CHS_AIN1				Bin(00000001)				//ADC 输入通道选择位为	AIN1
#define				CHS_AIN0				Bin(00000000)				//ADC 输入通道选择位为	AIN0
//******************************************************************************************
/////////////////////ADCON1控制寄存器各位定义///////////////////////////////////////////////
//******************************************************************************************
//Bit6:4] ADCKS[2:0]: ADC 时钟源选择位。
//ADCKS[2:0] ADC 时钟源选择
//000 Fcpu
//001 Fcpu/2
//010 Fcpu/4
//011 Fcpu/8
//100 Fcpu/16
//101 Fcpu/32
//110
//Fcpu/64
//111
//Bit[3:2] VREMS[1:0]: ADC 参考电压模式选择位。
//VREMS[1:0] ADC 参考电压模式
//00 VDD
//01 内部参考电压
//10 外部参考电压
//11 内部参考与外部参考连接
//Bit[1:0] VHS[1:0]: ADC 内建基准电平选择位。
//VREMS[1:0] 内建 VREF 基准电平
//00 关闭内部参考
//01 2.0V
//10 3.0V
//11 4.0V
#define				ADCKS_Fcpu				Bin(00000000)				//ADC 时钟源选择Fcpu
#define				ADCKS_Fcpu_2			Bin(00010000)				//ADC 时钟源选择Fcpu/2
#define				ADCKS_Fcpu_4			Bin(00100000)				//ADC 时钟源选择Fcpu/4
#define				ADCKS_Fcpu_8			Bin(00110000)				//ADC 时钟源选择Fcpu/8
#define				ADCKS_Fcpu_16			Bin(01000000)				//ADC 时钟源选择Fcpu/16
#define				ADCKS_Fcpu_32			Bin(01010000)				//ADC 时钟源选择Fcpu/32
#define				ADCKS_Fcpu_64			Bin(01100000)				//ADC 时钟源选择Fcpu/64
//#define				ADCKS_Fcpu_64			b'11110000'				;//ADC 时钟源选择Fcpu/64
#define				VREMS_00				Bin(00000000)				//ADC参考电压为VDD
#define				VREMS_01				Bin(00000100)				//ADC参考电压为内部参考电压
#define				VREMS_10				Bin(00001000)				//ADC参考电压为外部参考电压
#define				VREMS_11				Bin(00001100)				//ADC参考电压为内部参考与外部参考连接
#define				VHS_00					Bin(00000000)				//内建VREF基准电平关闭
#define				VHS_01					Bin(00000001)				//内建VREF基准电平为2V
#define				VHS_10					Bin(00000010)				//内建VREF基准电平为3V
#define				VHS_11					Bin(00000011)				//内建VREF基准电平为4V
//*************************************************************************
//=============================ADC初始化===================================
//*************************************************************************	
void  ADC_Init(void)
{
// 1、I/O设置	
// AIN1设置为模拟输入		
	OEA1 = 0;		//0:输入 1:输出
	ANSA1 = 1;
// 2、ADCON0设置---12位数据左对齐,通道12.ADCON0 设置
	ADCON0 = (unsigned char) (ADENB_1+ADS_0+EOC_0+ADFM_1+CHS_AIN1);
// 3、ADCON1设置---16MHz/16/1,参考是VDD	
	ADCON1 = (unsigned char)(ADCKS_Fcpu+VREMS_00+VHS_00);
// 4、ADCON3设置---0补偿
	ADCON2 = 0x00;
}



/*********************************END OF FILE************************************/ 
